package com.antai.sport.http.server.server.api.business.simplematch.service;

import com.antai.sport.http.server.common.exception.BusinessException;
import com.antai.sport.http.server.constants.DeleteStatus;
import com.antai.sport.http.server.repository.simplematch.entity.SimpleMatch;
import com.antai.sport.http.server.repository.simplematch.entity.SimpleMatchBanner;
import com.antai.sport.http.server.repository.simplematch.mapper.SimpleMatchBannerMapper;
import com.antai.sport.http.server.repository.simplematch.mapper.SimpleMatchMapper;
import com.antai.sport.http.server.server.api.business.simplematch.converter.SimpleMatchConverter;
import com.antai.sport.http.server.server.api.business.simplematch.dto.ReqSimpleMatchInit;
import com.antai.sport.http.server.server.api.business.simplematch.dto.RespSimpleMatchBanner;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@Service
public class SimpleMatchService {
    @Resource
    private SimpleMatchMapper simpleMatchMapper;
    @Resource
    private SimpleMatchBannerMapper simpleMatchBannerMapper;

    @Resource
    private SimpleMatchConverter simpleMatchConverter;

    /**
     * 创建比赛
     *
     * @param initData
     */
    public void init(ReqSimpleMatchInit initData) {
        if (StringUtils.isBlank(initData.getName())) {
            throw new BusinessException("比赛名称不能为空");
        }

        if (initData.getEntryTime() == null || initData.getStartTime() == null ||
                initData.getEndTime() == null) {
            throw new BusinessException("所有输入时间不能为空");
        }

        if (initData.getEntryTime().equals(initData.getStartTime()) ||
                initData.getEntryTime().isAfter(initData.getStartTime())) {
            throw new BusinessException("允许进入时间必须早于比赛开始时间");
        }

        if (initData.getStartTime().equals(initData.getEndTime()) ||
                initData.getStartTime().isAfter(initData.getEndTime())) {
            throw new BusinessException("比赛开始时间必须早于比赛结束时间");
        }

        SimpleMatch simpleMatch = simpleMatchConverter.toSimpleMatch(initData);
        simpleMatchMapper.insert(simpleMatch);
    }

    public List<RespSimpleMatchBanner> getSimpleMatchBannerList() {
        QueryWrapper<SimpleMatchBanner> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("deleted", DeleteStatus.UNDELETED)
                .orderBy(true, true, "show_order");
        List<SimpleMatchBanner> bannerList = simpleMatchBannerMapper.selectList(queryWrapper);
        return simpleMatchConverter.toRespBannerList(bannerList);
    }
}
